@@ -1,3 +1,7 @@
+(** @canonical Dune_action_plugin.Import *)
+module Import = Dune_action_plugin__Import
+
+
 (** @canonical Dune_action_plugin.Path *)
 module Path = Dune_action_plugin__Path
 
